<?php

namespace Eform\Instruction\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Eform\Instruction\Actions\InstructionsAction;
use Eform\Instruction\Http\Requests\InstructionsActionRequest;
use Eform\Instruction\Http\Resources\InstructionsResource;
use Eform\Instruction\Models\Instructions;

/**
 * Admin web controller class.
 */
class InstructionsActionController extends BaseController
{

    /**
     * Action controller function for instructions.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(InstructionsActionRequest $request, Instructions $instructions, $action)
    {
        try {
            $request = $request->all();
            $instructions = InstructionsAction::run($action, $instructions, $request);

            $data = new InstructionsResource($instructions);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('instruction::instructions.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('instruction/instructions/' . $instructions->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('instruction/instructions/' . $instructions->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
