<?php

namespace Eform\Instruction\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Eform\Instruction\Http\Requests\InstructionsActionsRequest;
use Eform\Instruction\Actions\InstructionsActions;

/**
 * Admin web controller class.
 */
class InstructionsActionsController extends BaseController
{

    /**
     * Action controller function for instructions.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(InstructionsActionsRequest $request, $action)
    {
        try {
            $instructions = InstructionsActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('instruction::instructions.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('instruction/instructions/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('instruction/instructions/' . $action))
                ->redirect();
        }
    }
}
