<?php

namespace Eform\Instruction\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Eform\Instruction\Events\InstructionsAction as InstructionsActionEvent;
use Eform\Instruction\Notifications\InstructionsAction as InstructionsActionNotification;
use Litepie\Actions\Concerns\AsAction;

class InstructionsAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the InstructionsActionEvent.
     *
     * @param   InstructionsActionEvent  $event
     * @return mixed
     */
    public function handle(InstructionsActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $instructions.
     *
     * @param   InstructionsActionEvent  $event
     * @return void
     */
    public function create(InstructionsActionEvent $event)
    {
        $client = $event->instructions->client;
        Notification::send($client, new InstructionsActionNotification($event));
    }

    /**
     * Handle the InstructionsActionEvent as a listener.
     *
     * @param   InstructionsActionEvent  $event
     * @return mixed
     */
    public function asListener(InstructionsActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   InstructionsActionEvent  $event
     * @return bool
     */
    private function isAllowed(InstructionsActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
